![NeuroM Logo](https://raw.githubusercontent.com/BlueBrain/NeuroM/master/doc/source/logo/NeuroM.jpg)



# NeuroM

NeuroM is a Python toolkit for the analysis and processing of neuron morphologies.

[![Run all tox python3](https://github.com/BlueBrain/NeuroM/actions/workflows/run-tox.yml/badge.svg)](https://github.com/BlueBrain/NeuroM/actions/workflows/run-tox.yml)
[![license](https://img.shields.io/pypi/l/neurom.svg)](https://github.com/BlueBrain/NeuroM/blob/master/LICENSE.txt)
[![codecov.io](https://codecov.io/github/BlueBrain/NeuroM/coverage.svg?branch=master)](https://codecov.io/github/BlueBrain/NeuroM?branch=master)
[![Documentation Status](https://readthedocs.org/projects/neurom/badge/?version=latest)](http://neurom.readthedocs.io/en/latest/?badge=latest)
[![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.597333.svg)](https://doi.org/10.5281/zenodo.597333)

## Documentation

NeuroM documentation is built and hosted on [readthedocs](https://readthedocs.org/).

* [latest snapshot](http://neurom.readthedocs.org/en/latest/)
* [latest release](http://neurom.readthedocs.org/en/stable/)

## Migration to v2 or v3 versions

Refer to [the doc page](https://neurom.readthedocs.io/en/latest/migration.html) on this topic.

## Reporting issues

Issues should be reported to the
[NeuroM github repository issue tracker](https://github.com/BlueBrain/NeuroM/issues).
The ability and speed with which issues can be resolved depends on how complete and
succinct the report is. For this reason, it is recommended that reports be accompanied
with
* A minimal but self-contained code sample that reproduces the issue. Minimal means no
  code that is irrelevant to the issue should be included. Self-contained means it should
  be possible to run the code without modifications and reproduce the problem.
* The observed and expected output and/or behaviour. If the issue is an error, the python
  error stack trace is extremely useful.
* The commit ID of the version used. This is particularly important if reporting an error
  from an older version of NeuroM.
* If reporting a regression, the commit ID of the change that introduced the problem
* If the issue depends on data, a data sample which reproduces the problem should be
  up-loaded. But check first whether the error can be reproduced with any of the data
  samples available in the `tests/data` directory.

## Citation

When you use the NeuroM software, we ask you to cite the following (**this includes poster presentations**):
[![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.597333.svg)](https://doi.org/10.5281/zenodo.597333)


## Funding & Acknowledgements
This work has been partially funded by the European Union’s Horizon 2020 Framework Programme for Research and Innovation under the Specific Grant Agreement No. 720270, 785907 (Human Brain Project SGA1/SGA2) and by the EBRAINS research infrastructure, funded from the European Union’s Horizon 2020 Framework Programme for Research and Innovation under the Specific Grant Agreement No. 945539 (Human Brain Project SGA3).

The development of this software was supported by funding to the Blue Brain Project, a research center of the École polytechnique fédérale de Lausanne (EPFL), from the Swiss government’s ETH Board of the Swiss Federal Institutes of Technology.

For license and authors, see `LICENSE.txt` and `AUTHORS.md` respectively.

Copyright (c) 2015-2022 Blue Brain Project/EPFL
